@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 67432 2011-04-11 00:02:30Z CJP $"
-__revision__ = "$Revision: 67432 $"
+__svnid__ = "$Id: Editra.py 71718 2012-06-12 13:25:48Z CJP $"
+__revision__ = "$Revision: 71718 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -66,6 +66,7 @@ import ed_event
 import updater
 import plugin
 import ed_ipc
+import ed_session
 import ebmlib
 from syntax import synglob
 
@@ -93,6 +94,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self._log = dev_tool.DEBUGP
         self._lock = False
         self._windows = dict()
+        self._isexiting = False
 
         # Disable debug popups
         wx.Log.EnableLogging(False)
@@ -108,7 +110,8 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         if ed_glob.SINGLE:
             # Setup the instance checker
             instance_name = u"%s-%s" % (self.GetAppName(), wx.GetUserId())
-            self._instance = wx.SingleInstanceChecker(instance_name)
+            lockpath = wx.StandardPaths.Get().GetTempDir()
+            self._instance = wx.SingleInstanceChecker(instance_name, path=lockpath)
             if self._instance.IsAnotherRunning():
                 try:
                     opts, args = ProcessCommandLine()
@@ -139,7 +142,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
                 # TODO: need to process other command line options as well i.e) -g
                 self._log("[app][info] Sending: %s" % exml.Xml)
-                rval = ed_ipc.SendCommands(exml, profiler.Profile_Get('SESSION_KEY'))
+                key = profiler.Profile_Get('SESSION_KEY')
+                if ebmlib.IsUnicode(key):
+                    key = key.encode(sys.getfilesystemencoding(), 'replace')
+                rval = ed_ipc.SendCommands(exml, key)
                 # If sending the command failed then let the editor startup
                 # a new instance
                 if not rval:
@@ -148,14 +154,17 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                 self._log("[app][info] Starting Ipc server...")
                 # Set the session key and save it to the users profile so
                 # that other instances can access the server
-                key = unicode(base64.b64encode(os.urandom(8), 'zZ'))
-                key = wx.GetUserName() + key
+                key = base64.b64encode(os.urandom(8), 'zZ')
+                uname = wx.GetUserName()
+                if ebmlib.IsUnicode(uname):
+                    uname = uname.encode(sys.getfilesystemencoding(), 'replace')
+                key = uname + key
                 profiler.Profile_Set('SESSION_KEY', key)
                 profiler.Profile_Set('ISBINARY', hasattr(sys, 'frozen'))
                 path = profiler.Profile_Get('MYPROFILE')
                 profiler.TheProfile.Write(path)
                 try:
-                    self._server = ed_ipc.EdIpcServer(self, profiler.Profile_Get('SESSION_KEY'))
+                    self._server = ed_ipc.EdIpcServer(self, key)
                     self._server.start()
                 except Exception, msg:
                     self._log("[app][err] Failed to start ipc server")
@@ -211,12 +220,19 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         # Setup Locale
         locale.setlocale(locale.LC_ALL, '')
-        self.locale = wx.Locale(ed_i18n.GetLangId(profiler.Profile_Get('LANG')))
-        if self.locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
-            self.locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
-            self.locale.AddCatalog(ed_glob.PROG_NAME)
+        langId = ed_i18n.GetLangId(profiler.Profile_Get('LANG'))
+        if wx.Locale.IsAvailable(langId):
+            self.locale = wx.Locale(langId)
+            if self.locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
+                self._log("[app][info] Loaded Locale '%s'" % self.locale.CanonicalName)
+                self.locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
+                self.locale.AddCatalog(ed_glob.PROG_NAME)
+            else:
+                self._log("[app][err] Unknown Locale '%s'" % self.locale.CanonicalName)
+                del self.locale
+                self.locale = None
         else:
-            del self.locale
+            self._log("[app][err] The locale %s is not available!" %  profiler.Profile_Get('LANG'))
             self.locale = None
 
         # Check and set encoding if necessary
@@ -277,10 +293,11 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         @postcondition: Program may remain open if an open window is locking.
 
         """
+        self._isexiting = True
         self._pluginmgr.WritePluginConfig()
         profiler.TheProfile.Write(profiler.Profile_Get('MYPROFILE'))
         if not self._lock or force:
-            if hasattr(self, '_server'):
+            if getattr(self, '_server', None):
                 self._server.Shutdown()
 
             try:
@@ -315,10 +332,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         self._log("[app][warn] Editra::GetMainWindow is deprecated")
         for window in self._windows:
-            if not hasattr(self._windows[window][0], '__name__'):
-                continue
-
-            if self._windows[window][0].__name__ == "MainWindow":
+            if isinstance(self._windows[window][0], ed_main.MainWindow):
                 return self._windows[window][0]
         return None
 
@@ -367,7 +381,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         mainw = list()
         for window in self._windows:
             try:
-                if self._windows[window][0].__name__ == "MainWindow":
+                if isinstance(self._windows[window][0], ed_main.MainWindow):
                     mainw.append(self._windows[window][0])
             except AttributeError:
                 continue
@@ -490,8 +504,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
     def OnActivate(self, evt):
         """Activation Event Handler
-        @param evt: event that called this handler
-        @type evt: wx.ActivateEvent
+        @param evt: wx.ActivateEvent
 
         """
         if evt.GetActive():
@@ -510,7 +523,8 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
     def OnExit(self, evt=None, force=False):
         """Handle application exit request
-        @param evt: event that called this handler
+        @keyword evt: event that called this handler
+        @keyword force: Force an exit
 
         """
         e_id = -1
@@ -518,18 +532,21 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             e_id = evt.GetId()
 
         if e_id == ed_glob.ID_EXIT:
+            self._isexiting = True
             # First loop is to ensure current top window is
             # closed first
             for win in self.GetMainWindows():
                 if win.IsActive():
                     result = win.Close()
                     if result:
+                        self._isexiting = False
                         break
                     return
             for win in self.GetMainWindows():
                 win.Raise()
                 result = win.Close()
                 if not result:
+                    self._isexiting = False
                     break
             self.Exit(force)
         else:
@@ -552,6 +569,11 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         @todo: move command processing into own module
 
         """
+        # Guard against events that come in after shutdown
+        # from server thread.
+        if not self or self._isexiting or not self.IsMainLoopRunning():
+            return
+
         self._log("[app][info] IN OnCommandReceived")
         cmds = evt.GetCommands()
         if isinstance(cmds, ed_ipc.IPCCommand):
@@ -591,6 +613,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
     def OpenNewWindow(self, fname=u'', caller=None):
         """Open a new window
         @keyword fname: Open a file in the new window
+        @keyword caller: MainWindow that called to open this one
         @return: the new window
 
         """
@@ -762,17 +785,24 @@ def InitConfig():
             if ed_glob.CONFIG['ISLOCAL']:
                 pstr = os.path.join(ed_glob.CONFIG['PROFILE_DIR'], pstr)
             pstr = util.RepairConfigState(pstr)
+            dev_tool.DEBUGP("[InitConfig][info] Loading profile: %s" % repr(pstr))
             profiler.TheProfile.Load(pstr)
         else:
             dev_tool.DEBUGP("[InitConfig][info] Updating Profile to current version")
 
+            # When upgrading from an older version make sure all
+            # config directories are available.
+            for cfg in ("cache", "styles", "plugins", "profiles", "sessions"):
+                if not util.HasConfigDir(cfg):
+                    util.MakeConfigDir(cfg)
+
             # Load and update profile
             pstr = profiler.GetProfileStr()
             pstr = util.RepairConfigState(pstr)
             profiler.TheProfile.Load(pstr)
             profiler.TheProfile.Update()
 
-            #---- Temporary Profile Adaptions ----#
+            #---- Temporary Profile Adaption ----#
 
             # Added after 0.5.32
             mconfig = profiler.Profile_Get('LEXERMENU', default=None)
@@ -805,21 +835,22 @@ def InitConfig():
 
             # After 0.4.65 LAST_SESSION now points a session file and not
             # to a list of files to open.
+            ed_glob.CONFIG['SESSION_DIR'] = util.ResolvConfigDir(u"sessions")
+            smgr = ed_session.EdSessionMgr()
             sess = profiler.Profile_Get('LAST_SESSION')
-            if isinstance(sess, list):
-                profiler.Profile_Set('LAST_SESSION', u'')
+            if isinstance(sess, list) or not sess:
+                profiler.Profile_Set('LAST_SESSION', smgr.DefaultSession)
+            else:
+                # After 0.6.58 session is reduced to a name instead of path
+                if sess and os.path.sep in sess:
+                    name = smgr.SessionNameFromPath(sess)
+                    profiler.Profile_Set('LAST_SESSION', name)
 
-            #---- End Temporary Profile Adaptions ----#
+            #---- End Temporary Profile Adaption ----#
 
             # Write out updated profile
             profiler.TheProfile.Write(pstr)
 
-            # When upgrading from an older version make sure all
-            # config directories are available.
-            for cfg in ("cache", "styles", "plugins", "profiles", "sessions"):
-                if not util.HasConfigDir(cfg):
-                    util.MakeConfigDir(cfg)
-
             profile_updated = True
     else:
         # Fresh install
@@ -944,7 +975,7 @@ def PrintHelp(err=None):
         sys.stderr.write(err + os.linesep)
 
     print(("Editra - %s - Developers Text Editor\n"
-       "Cody Precord (2005-2010)\n\n"
+       "Cody Precord (2005-2012)\n\n"
        "usage: Editra [arguments] [files... ]\n\n"
        "Short Arguments:\n"
        "  -c    Set custom configuration directory at runtime\n"
@@ -1094,12 +1125,13 @@ def _Main(opts, args):
     # Load Session Data
     # But not if there are command line args for files to open
     if profiler.Profile_Get('SAVE_SESSION', 'bool', False) and not len(args):
+        smgr = ed_session.EdSessionMgr()
         session = profiler.Profile_Get('LAST_SESSION', default=u'')
         if isinstance(session, list):
             # Check for format conversion from previous versions
-            profiler.Profile_Set('LAST_SESSION', u'')
-        else:
-            frame.GetNotebook().LoadSessionFile(session)
+            profiler.Profile_Set('LAST_SESSION', smgr.DefaultSession)
+            session = smgr.DefaultSession
+        frame.GetNotebook().LoadSessionFile(session)
         del session
 
     # Unlike wxMac/wxGTK Windows doesn't post an activate event when a window
