@@ -6,7 +6,8 @@
 # License: wxWindows License                                                  #
 ###############################################################################
 
-"""
+"""@package Editra.src.ed_search
+
 Provides text searching services, utilities, and ui components for searching
 text documents and files.
 
@@ -15,14 +16,15 @@ text documents and files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 67431 2011-04-10 17:07:56Z CJP $"
-__revision__ = "$Revision: 67431 $"
+__svnid__ = "$Id: ed_search.py 71673 2012-06-06 20:12:42Z CJP $"
+__revision__ = "$Revision: 71673 $"
 
 #--------------------------------------------------------------------------#
 # Imports
 import os
 import sys
 import re
+import unicodedata
 import wx
 
 # Local imports
@@ -35,6 +37,7 @@ from profiler import Profile_Get, Profile_Set
 import eclib
 import ebmlib
 import ed_basewin
+import ed_thread
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -48,7 +51,7 @@ class EdSearchEngine(ebmlib.SearchEngine):
                  matchcase=True, wholeword=False):
         super(EdSearchEngine, self).__init__(query, regex, down,
                                              matchcase, wholeword)
-        # Atttributes
+        # Attributes
         self._offset = 0
 
     def FormatResult(self, fname, lnum, match):
@@ -81,11 +84,18 @@ class EdSearchEngine(ebmlib.SearchEngine):
 
     def SetQuery(self, query):
         """Set the query string"""
-        if ebmlib.IsUnicode(query):
-            # Encode to UTF-8 as used internally by the stc
-            query = query.encode('utf-8')
+        if not ebmlib.IsUnicode(query):
+            query = query.decode('utf-8')
+        query = unicodedata.normalize('NFC', query)
         super(EdSearchEngine, self).SetQuery(query)
 
+    def SetSearchPool(self, pool):
+        """Set the search pool"""
+        if not ebmlib.IsUnicode(pool):
+            pool = pool.decode('utf-8')
+        pool = unicodedata.normalize('NFC', pool)
+        super(EdSearchEngine, self).SetSearchPool(pool)
+
 #--------------------------------------------------------------------------#
 
 class SearchController(object):
@@ -102,7 +112,7 @@ class SearchController(object):
         self._parent   = owner
         self._stc      = getstc
         self._finddlg  = None
-        self._posinfo  = dict(scroll=0, start=0, found=0, ldir=None)
+        self._posinfo  = dict(scroll=0, start=0, found=-1, ldir=None)
         self._data     = self._InitFindData()
         self._li_choices = list()
         self._li_sel   = 0
@@ -140,20 +150,21 @@ class SearchController(object):
         # TODO: find out why parent is not a Window in some cases...
         if not isinstance(self._parent, wx.Window):
             parent = wx.GetApp().GetActiveWindow()
+            self._parent = parent
         else:
             parent = self._parent
 
+        labels = (_("Find"), _("Find/Replace"))
         if e_id == ed_glob.ID_FIND_REPLACE:
-            dlg = eclib.AdvFindReplaceDlg(parent, self._data,
-                                          (_("Find"), _("Find/Replace")),
+            dlg = eclib.AdvFindReplaceDlg(parent, self._data, labels,
                                           eclib.AFR_STYLE_REPLACEDIALOG)
         elif e_id == ed_glob.ID_FIND:
-            dlg = eclib.AdvFindReplaceDlg(parent, self._data,
-                                          (_("Find"), _("Find/Replace")))
+            dlg = eclib.AdvFindReplaceDlg(parent, self._data, labels)
         else:
             dlg = None
 
         # Change the icons to use ones from Editra's ArtProvider
+        # Customize current context / state
         if dlg is not None:
             find = wx.ArtProvider.GetBitmap(str(ed_glob.ID_FIND), wx.ART_MENU)
             replace = wx.ArtProvider.GetBitmap(str(ed_glob.ID_FIND_REPLACE),
@@ -165,6 +176,18 @@ class SearchController(object):
                 dlg.SetReplaceBitmap(replace)
 
             # Set the persisted data from the last time the dialog was shown
+            def GetCurrentDir():
+                """Get current directory for dialog context
+                @return: unicode
+
+                """
+                fname = u""
+                if self:
+                    cbuff = self._stc()
+                    fname = getattr(cbuff, 'GetFileName', lambda: u"")()
+                return os.path.dirname(fname)
+
+            dlg.SetDirectoryGetter(GetCurrentDir)
             dlg.SetLookinChoices(self._li_choices)
             dlg.SetLookinSelection(self._li_sel)
             dlg.SetFileFilters(self._filters)
@@ -178,7 +201,7 @@ class SearchController(object):
 
         """
         data = msg.GetData()
-        if data.get('mainw', None) == self._parent.GetTopLevelParent():
+        if data.get('mainw', None) == self._parent.TopLevelParent:
 
             if 'findtxt' in data:
                 self.SetQueryString(data.get('findtxt'))
@@ -303,7 +326,6 @@ class SearchController(object):
         if the last search resulted in nothing being found then the
         return value will -1.
         @return: position of last search operation
-        @rtype: int
 
         """
         return self._posinfo['found']
@@ -329,9 +351,9 @@ class SearchController(object):
                                      True, evt.IsMatchCase(), evt.IsWholeWord())
 
         if mode == eclib.LOCATION_CURRENT_DOC:
-            engine.SetSearchPool(stc.GetTextRaw())
+            engine.SetSearchPool(stc.GetText())
         elif mode == eclib.LOCATION_IN_SELECTION:
-            engine.SetSearchPool(stc.GetSelectedTextRaw())
+            engine.SetSearchPool(stc.GetSelectedText())
         else:
             # TODO: report that this is not supported yet
             #       this case should not happen as the count button is currently
@@ -349,10 +371,11 @@ class SearchController(object):
                       _("Find Count"),
                       wx.ICON_INFORMATION|wx.OK)
 
-    def OnFind(self, evt, findnext=False):
+    def OnFind(self, evt, findnext=False, incremental=False):
         """Do an incremental search in the currently buffer
         @param evt: EVT_FIND, EVT_FIND_NEXT
         @keyword findnext: force a find next action
+        @keyword incremental: perform an incremental search
 
         """
         data = self.GetData()
@@ -393,38 +416,37 @@ class SearchController(object):
 
         # XXX: may be inefficient to copy whole buffer each time for files
         #      that are large.
-        self._engine.SetSearchPool(stc.GetTextRaw())
-
-        # Check if the direction changed
-        ldir = self._posinfo['ldir']
-        if isdown:
-            self._posinfo['ldir'] = 'down'
-        else:
-            self._posinfo['ldir'] = 'up'
+        self._engine.SetSearchPool(stc.GetText())
 
         # Get the search start position
         if evt.GetEventType() == eclib.edEVT_FIND:
-            spos = self._posinfo['found']
+            if not incremental:
+                spos = stc.CurrentPos
+            else:
+                # For incremental search redo search starting from last found
+                # position.
+                spos = self._posinfo['found']
+                if spos < 0:
+                    spos = stc.CurrentPos
         else:
-            spos = stc.GetCurrentPos()
-            if ldir != self._posinfo['ldir']:
-                start, end = stc.GetSelection()
-                if ldir == 'down':
-                    spos = start
+            spos = stc.CurrentPos
+            start, end = stc.GetSelection()
+            if start != end:
+                if isdown:
+                    spos = max(start, end)
                 else:
-                    spos = end
+                    spos = min(start, end)
 
         # Do the find
         match = self._engine.Find(spos)
         if match is not None:
             start, end = match
-
             if isdown:
                 start = start + spos
                 end = end + spos
                 stc.SetSelection(start, end)
             else:
-                stc.SetSelection(end, start)
+                stc.SetSelection(start, end)
 
             # Ensure caret and the line its in is exposed
             stc.EnsureCaretVisible()
@@ -449,17 +471,12 @@ class SearchController(object):
 
             if match is not None:
                 start, end = match
-
                 self._posinfo['found'] = start
-
-                match = list(match)
-                if not isdown:
-                    match.reverse()
-                stc.SetSelection(match[0], match[1])
+                stc.SetSelection(start, end)
                 
                 # Ensure caret and the line its in is exposed
                 stc.EnsureCaretVisible()
-                line = stc.LineFromPosition(match[0])
+                line = stc.LineFromPosition(start)
                 stc.EnsureVisible(line)
             else:
                 self._posinfo['found'] = -1
@@ -492,7 +509,7 @@ class SearchController(object):
                 ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH,
                                    (engine.SearchInFile, [fname,], dict()))
             else:
-                engine.SetSearchPool(stc.GetTextRaw())
+                engine.SetSearchPool(stc.GetText())
                 ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH,
                                    (engine.FindAllLines,))
         if smode == eclib.LOCATION_IN_SELECTION:
@@ -500,7 +517,7 @@ class SearchController(object):
             sel_s = min(stc.GetSelection())
             offset = stc.LineFromPosition(sel_s)
             engine.SetOffset(offset)
-            engine.SetSearchPool(stc.GetSelectedTextRaw())
+            engine.SetSearchPool(stc.GetSelectedText())
             ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH,
                                (engine.FindAllLines,))
         elif smode == eclib.LOCATION_OPEN_DOCS:
@@ -625,14 +642,14 @@ class SearchController(object):
         results = 0
         if smode == eclib.LOCATION_CURRENT_DOC:
             stc = self._stc()
-            engine.SetSearchPool(stc.GetTextRaw())
+            engine.SetSearchPool(stc.GetText())
             matches = engine.FindAll()
             if matches is not None:
                 self.ReplaceInStc(stc, matches, rstring, evt.IsRegEx())
                 results = len(matches)
         elif smode == eclib.LOCATION_IN_SELECTION:
             stc = self._stc()
-            engine.SetSearchPool(stc.GetSelectedTextRaw())
+            engine.SetSearchPool(stc.GetSelectedText())
             matches = engine.FindAll()
             if matches is not None:
                 self.ReplaceInStcSelection(stc, matches, rstring, evt.IsRegEx())
@@ -652,7 +669,7 @@ class SearchController(object):
                 pass # TODO: notify of no matches?
         elif smode == eclib.LOCATION_OPEN_DOCS:
             for ctrl in self._parent.GetTextControls():
-                engine.SetSearchPool(ctrl.GetTextRaw())
+                engine.SetSearchPool(ctrl.GetText())
                 matches = engine.FindAll()
                 if matches is not None:
                     self.ReplaceInStc(ctrl, matches, rstring, evt.IsRegEx())
@@ -739,44 +756,52 @@ class SearchController(object):
         @param stc: StyledTextCtrl
         @param matches: list of match objects
         @param rstring: Replace string
+        @keyword isregex: Is it a regular expression operation (bool)
 
         """
-        stc.BeginUndoAction()
-        for match in reversed(matches):
-            start, end = match.span()
+        if not len(matches):
+            return
+        def GetSub(match):
+            """replace substitution callable for re.sub"""
+            value = rstring
             if isregex:
                 try:
-                    value = match.expand(rstring.encode('utf-8')).decode('utf-8')
-                except re.error, err:
-                    msg = _("Error in regular expression expansion."
-                            "The replace action cannot be completed.\n\n"
-                            "Error Message: %s") % err.message
-                    wx.MessageBox(msg, _("Replace Error"), wx.OK|wx.ICON_ERROR)
-                    break
-            else:
-                value = rstring
-            stc.SetTargetStart(start)
-            stc.SetTargetEnd(end)
-            stc.ReplaceTarget(value)
-        stc.EndUndoAction()
+                    value = match.expand(rstring)
+                except:
+                    pass
+            return value
+        text = re.sub(matches[0].re, GetSub, stc.GetText())
+        # Update the view
+        with eclib.Freezer(stc) as _tmp:
+            stc.BeginUndoAction()
+            cpos = stc.CurrentPos
+            stc.ClearAll()
+            stc.SetText(text)
+            stc.GotoPos(cpos)
+            stc.EndUndoAction()
 
     @staticmethod
     def ReplaceInStcSelection(stc, matches, rstring, isregex=True):
         """Replace all the matches in the selection"""
-        sel_s = min(stc.GetSelection())
-        stc.BeginUndoAction()
-        for match in reversed(matches):
-            start, end = match.span()
-            start += sel_s
-            end += sel_s
+        if not len(matches):
+            return
+        def GetSub(match):
+            """replace substitution callable for re.sub"""
+            value = rstring
             if isregex:
-                value = match.expand(rstring.encode('utf-8')).decode('utf-8')
-            else:
-                value = rstring
-            stc.SetTargetStart(start)
-            stc.SetTargetEnd(end)
-            stc.ReplaceTarget(value)
-        stc.EndUndoAction()
+                try:
+                    value = match.expand(rstring)
+                except:
+                    pass
+            return value
+        text = re.sub(matches[0].re, GetSub, stc.GetSelectedText())
+        # Update the view
+        with eclib.Freezer(stc) as _tmp:
+            stc.BeginUndoAction()
+            start, end = stc.GetSelection()
+            stc.ReplaceSelection(text)
+            stc.SetSelection(start, start+len(text))
+            stc.EndUndoAction()
 
     def SetFileFilters(self, filters):
         """Set the file filter to use
@@ -829,7 +854,13 @@ class EdSearchCtrl(wx.SearchCtrl):
                  pos=wx.DefaultPosition, size=wx.DefaultSize, \
                  style=wx.TE_RICH2|wx.TE_PROCESS_ENTER):
         """Initializes the Search Control
-        @param menulen: max length of history menu
+        @param parent: parent window
+        @param id_: control id
+        @keyword value: default value
+        @keyword menulen: max length of history menu
+        @keyword pos: control position (tuple)
+        @keyword size: control size (tuple)
+        @keyword style: control style bitmask
 
         """
         super(EdSearchCtrl, self).__init__(parent, id_, value, pos, size, style)
@@ -838,7 +869,6 @@ class EdSearchCtrl(wx.SearchCtrl):
         self._parent     = parent
         # TEMP HACK
         self.FindService = self.GetTopLevelParent().GetNotebook()._searchctrl
-        self._flags      = 0
         self._recent     = list()        # The History List
         self._last       = None
         self.rmenu       = wx.Menu()
@@ -856,13 +886,29 @@ class EdSearchCtrl(wx.SearchCtrl):
             for child in self.GetChildren():
                 if isinstance(child, wx.TextCtrl):
                     child.Bind(wx.EVT_KEY_UP, self.ProcessEvent)
+                    child.Bind(wx.EVT_KEY_DOWN, self.ProcessEvent)
                     self._txtctrl = child
                     break
         else:
             self.Bind(wx.EVT_KEY_UP, self.ProcessEvent)
+            self.Bind(wx.EVT_KEY_DOWN, self.ProcessEvent)
         self.Bind(wx.EVT_SEARCHCTRL_CANCEL_BTN, self.OnCancel)
         self.Bind(wx.EVT_MENU, self.OnHistMenu)
 
+    #---- Properties ----#
+    def __GetFlags(self):
+        flags = 0
+        data = self.GetSearchData()
+        if data:
+            flags = data.GetFlags()
+        return flags
+    def __SetFlags(self, flags):
+        data = self.GetSearchData()
+        if data:
+            data.SetFlags(flags)
+    SearchFlags = property(lambda self: self.__GetFlags(),
+                           lambda self, flags: self.__SetFlags(flags))
+
     #---- Functions ----#
     def AutoSetQuery(self, multiline=False):
         """Autoload a selected string from the controls client buffer"""
@@ -880,35 +926,35 @@ class EdSearchCtrl(wx.SearchCtrl):
         if data is not None:
             c_flags = data.GetFlags()
             c_flags ^= flag
-            self._flags = c_flags
-            data.SetFlags(self._flags)
+            self.SearchFlags = c_flags
             self.FindService.RefreshControls()
 
     def FindAll(self):
         """Fire off a FindAll job in the current buffer"""
-        evt = eclib.FindEvent(eclib.edEVT_FIND_ALL, flags=self._flags)
+        evt = eclib.FindEvent(eclib.edEVT_FIND_ALL, flags=self.SearchFlags)
         evt.SetFindString(self.GetValue())
         self.FindService.OnFindAll(evt)
 
-    def DoSearch(self, next=True):
+    def DoSearch(self, next=True, incremental=False):
         """Do the search and move the selection
         @keyword next: search next or previous
+        @keyword incremental: is this an incremental search
 
         """
         s_cmd = eclib.edEVT_FIND
         if not next:
             self.SetSearchFlag(eclib.AFR_UP)
         else:
-            if eclib.AFR_UP & self._flags:
+            if eclib.AFR_UP & self.SearchFlags:
                 self.ClearSearchFlag(eclib.AFR_UP)
 
         if self.GetValue() == self._last:
             s_cmd = eclib.edEVT_FIND_NEXT
 
-        evt = eclib.FindEvent(s_cmd, flags=self._flags)
+        evt = eclib.FindEvent(s_cmd, flags=self.SearchFlags)
         self._last = self.GetValue()
         evt.SetFindString(self.GetValue())
-        self.FindService.OnFind(evt)
+        self.FindService.OnFind(evt, incremental=incremental)
 
         # Give feedback on whether text was found or not
         if self.FindService.GetLastFound() < 0 and len(self.GetValue()) > 0:
@@ -937,8 +983,7 @@ class EdSearchCtrl(wx.SearchCtrl):
 
     def GetSearchData(self):
         """Gets the find data from the controls FindService
-        @return: search data
-        @rtype: wx.FindReplaceData
+        @return: wx.FindReplaceData
 
         """
         if hasattr(self.FindService, "GetData"):
@@ -989,7 +1034,6 @@ class EdSearchCtrl(wx.SearchCtrl):
         """Returns True if the search control is set to search
         in Match Case mode.
         @return: whether search is using match case or not
-        @rtype: boolean
 
         """
         data = self.GetSearchData()
@@ -1001,7 +1045,6 @@ class EdSearchCtrl(wx.SearchCtrl):
         """Returns True if the search control is set to search
         in regular expression mode.
         @return: whether search is using regular expressions or not
-        @rtype: boolean
 
         """
         data = self.GetSearchData()
@@ -1012,8 +1055,7 @@ class EdSearchCtrl(wx.SearchCtrl):
     def IsSearchPrevious(self):
         """Returns True if the search control is set to search
         in Previous mode.
-        @return: whether search is searchin up or not
-        @rtype: boolean
+        @return: whether search is searching up or not
 
         """
         data = self.GetSearchData()
@@ -1025,7 +1067,6 @@ class EdSearchCtrl(wx.SearchCtrl):
         """Returns True if the search control is set to search
         in Whole Word mode.
         @return: whether search is using match whole word or not
-        @rtype: boolean
 
         """
         data = self.GetSearchData()
@@ -1058,8 +1099,7 @@ class EdSearchCtrl(wx.SearchCtrl):
         if data is not None:
             c_flags = data.GetFlags()
             c_flags |= flags
-            self._flags = c_flags
-            data.SetFlags(self._flags)
+            self.SearchFlags = c_flags
             self.FindService.RefreshControls()
 
     #---- End Functions ----#
@@ -1070,11 +1110,19 @@ class EdSearchCtrl(wx.SearchCtrl):
         @param evt: the event that called this handler
 
         """
+        e_key = evt.GetKeyCode()
         if evt.GetEventType() != wx.wxEVT_KEY_UP:
-            evt.Skip()
+            if e_key in (wx.WXK_UP, wx.WXK_DOWN):
+                buff = wx.GetApp().GetCurrentBuffer()
+                if isinstance(buff, wx.stc.StyledTextCtrl):
+                    val = -1
+                    if e_key == wx.WXK_DOWN:
+                        val = 1
+                    buff.ScrollLines(val)
+            else:
+                evt.Skip()
             return
 
-        e_key = evt.GetKeyCode()
         if e_key == wx.WXK_ESCAPE:
             # TODO change to more safely determine the context
             # Currently control is only used in command bar
@@ -1111,11 +1159,11 @@ class EdSearchCtrl(wx.SearchCtrl):
             # Don't do incremental searches when the RegEx flag is set in order
             # to avoid errors in compiling the expression
             if not self.IsRegEx():
-                self.DoSearch(next=True)
+                self.DoSearch(next=True, incremental=True)
 
     def OnCancel(self, evt):
         """Cancels the Search Query
-        @param evt: the event that called this handler
+        @param evt: SearchCtrl event
 
         """
         self.SetValue(u"")
@@ -1124,8 +1172,7 @@ class EdSearchCtrl(wx.SearchCtrl):
 
     def OnHistMenu(self, evt):
         """Sets the search controls value to the selected menu item
-        @param evt: the event that called this handler
-        @type evt: wx.MenuEvent
+        @param evt: wx.MenuEvent
 
         """
         item_id = evt.GetId()
@@ -1279,7 +1326,7 @@ class SearchResultScreen(ed_basewin.EdBaseCtrlBox):
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
 
     def OnDestroy(self, evt):
-        if evt.GetId() == self.GetId():
+        if evt.Id == self.Id:
             ed_msg.Unsubscribe(self.OnThemeChange)
         evt.Skip()
 
@@ -1360,6 +1407,8 @@ class SearchResultScreen(ed_basewin.EdBaseCtrlBox):
     def StartSearch(self, searchmeth, *args, **kwargs):
         """Start a search with the given method and display the results
         @param searchmeth: callable
+        @param *args: positional arguments to pass to searchmeth
+        @param **kwargs: keyword arguments to pass to searchmeth
 
         """
         self._meth = searchmeth
@@ -1368,8 +1417,8 @@ class SearchResultScreen(ed_basewin.EdBaseCtrlBox):
             self._job.Cancel()
 
         self._list.Clear()
-        self._job = eclib.TaskThread(self._list, searchmeth, *args, **kwargs)
-        self._job.start()
+        self._job = eclib.TaskObject(self._list, searchmeth, *args, **kwargs)
+        ed_thread.EdThreadPool().QueueJob(self._job.DoTask)
         self._cancelb.Enable()
 
 #-----------------------------------------------------------------------------#
@@ -1415,9 +1464,9 @@ class SearchResultList(eclib.OutputBuffer):
             # of updating the status bar and to improve performance of search.
             if self._files == 1 or \
                ((self._files / 10) > ((self._files-1) / 10)): 
-                ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
-                                   (ed_glob.SB_INFO,
-                                   _("Searching in: %s") % value[1]))
+                wx.CallAfter(ed_msg.PostMessage, ed_msg.EDMSG_UI_SB_TXT,
+                             (ed_glob.SB_INFO,
+                              value[1])) # GetTranslation not thread safe (_("Searching in: %s") % )
 
     def ApplyStyles(self, start, txt):
         """Set a hotspot for each search result
