@@ -5,7 +5,7 @@
 # Author:      Rob McMullen
 #
 # Created:     2008
-# RCS-ID:      $Id: stcspellcheck.py 62175 2009-09-28 00:10:31Z CJP $
+# RCS-ID:      $Id: stcspellcheck.py 69791 2011-11-19 22:02:59Z CJP $
 # Copyright:   (c) 2008 Rob McMullen
 # License:     wxWidgets
 #-----------------------------------------------------------------------------
@@ -223,7 +223,15 @@ class STCSpellCheck(object):
         """
         cls._spelling_lang = lang
         cls._spelling_dict = cls._getDict(lang)
-    
+
+    @classmethod
+    def getSpellingDictionary(cls):
+        """Get the currently used spelling dictionary
+        @return: enchant.Dict instance or None
+
+        """
+        return cls._spelling_dict
+
     def setLanguage(self, lang):
         """Set the language for spelling check for this class, if different than
         the default.
