@@ -21,8 +21,8 @@ LANGUAGE: Python
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synextreg.py 67392 2011-04-04 21:06:43Z CJP $"
-__revision__ = "$Revision: 67392 $"
+__svnid__ = "$Id: synextreg.py 70228 2011-12-31 20:39:16Z CJP $"
+__revision__ = "$Revision: 70228 $"
 
 #-----------------------------------------------------------------------------#
 import os
@@ -98,6 +98,8 @@ ID_LANG_EDJE = _NewId()
 LANG_EDJE = u'Edje'
 ID_LANG_FERITE = _NewId()
 LANG_FERITE = u'Ferite'
+ID_LANG_GLSL = _NewId()
+LANG_GLSL = u'GLSL'
 ID_LANG_HAXE = _NewId()
 LANG_HAXE = u'HaXe'
 ID_LANG_JAVA = _NewId()
@@ -340,6 +342,7 @@ EXT_MAP = {
            'fe'                 : LANG_FERITE,
            'fth 4th fs seq'     : LANG_FORTH,
            'prg'                : LANG_FLAGSHIP,
+           'frag vert glsl'     : LANG_GLSL,
            'gc gui'             : LANG_GUI4CLI,
            'hs'                 : LANG_HASKELL,
            'hx hxml'            : LANG_HAXE,
@@ -401,18 +404,14 @@ EXT_MAP = {
 
 class ExtensionRegister(dict):
     """A data storage class for managing mappings of
-    file types to file extensions. The register is created
-    as a singleton.
-    @status: initial implementation
+    file types to file extensions. The register is created as a singleton.
 
     """
     instance = None
-    first = True
     config = u'synmap'
     def __init__(self):
         """Initializes the register"""
-        if self.first:
-            self.first = False
+        if not ExtensionRegister.instance:
             self.LoadDefault()
 
     def __new__(cls, *args, **kargs):
@@ -500,13 +499,15 @@ class ExtensionRegister(dict):
 
     def FileTypeFromExt(self, ext):
         """Returns the file type that is associated with
-        the extension. If no association is found Plain Text
+        the extension. Matching is done with a case insensitive search.
+        If no association is found Plain Text
         will be returned by default.
         @param ext: extension to lookup
 
         """
+        ext = ext.lower()
         for key, val in self.iteritems():
-            if ext in val:
+            if ext in [ext2.lower() for ext2 in val]:
                 return key
         return LANG_TXT
 
