@@ -22,7 +22,7 @@ class RichTextFrame(wx.Frame):
 
         self.rtc.BeginParagraphSpacing(0, 20)
 
-        self.rtc.BeginAlignment(rt.TEXT_ALIGNMENT_CENTRE)
+        self.rtc.BeginAlignment(wx.TEXT_ALIGNMENT_CENTRE)
         self.rtc.BeginBold()
 
         self.rtc.BeginFontSize(14)
@@ -37,7 +37,7 @@ class RichTextFrame(wx.Frame):
         self.rtc.EndBold()
 
         self.rtc.Newline()
-        self.rtc.WriteImage(images.get_rt_zebraImage())
+        self.rtc.WriteImage(images._rt_zebra.GetImage())
 
         self.rtc.EndAlignment()
 
@@ -45,7 +45,7 @@ class RichTextFrame(wx.Frame):
         self.rtc.Newline()
 
         self.rtc.WriteText("What can you do with this thing? ")
-        self.rtc.WriteImage(images.get_rt_smileyImage())
+        self.rtc.WriteImage(images._rt_smiley.GetImage())
         self.rtc.WriteText(" Well, you can change text ")
 
         self.rtc.BeginTextColour((255, 0, 0))
@@ -119,8 +119,8 @@ class RichTextFrame(wx.Frame):
 
         self.rtc.WriteText("The following paragraph is right-aligned with 1.5 line spacing:")
 
-        self.rtc.BeginAlignment(rt.TEXT_ALIGNMENT_RIGHT)
-        self.rtc.BeginLineSpacing(rt.TEXT_ATTR_LINE_SPACING_HALF)
+        self.rtc.BeginAlignment(wx.TEXT_ALIGNMENT_RIGHT)
+        self.rtc.BeginLineSpacing(wx.TEXT_ATTR_LINE_SPACING_HALF)
         self.rtc.Newline()
 
         self.rtc.WriteText("It was in January, the most down-trodden month of an Edinburgh winter. An attractive woman came into the cafe, which is nothing remarkable.")
@@ -169,12 +169,103 @@ class RichTextFrame(wx.Frame):
 
         self.rtc.WriteText("Note: this sample content was generated programmatically from within the MyFrame constructor in the demo. The images were loaded from inline XPMs. Enjoy wxRichTextCtrl!")
 
+        self.rtc.Newline()
+        self.rtc.Newline()
+        self.rtc.BeginFontSize(12)
+        self.rtc.BeginBold()
+        self.rtc.WriteText("Additional comments by David Woods:")
+        self.rtc.EndBold()
+        self.rtc.EndFontSize()
+        self.rtc.Newline()
+        self.rtc.WriteText("I find some of the RichTextCtrl method names, as used above, to be misleading.  Some character styles are stacked in the RichTextCtrl, and they are removed in the reverse order from how they are added, regardless of the method called.  Allow me to demonstrate what I mean.")
+        self.rtc.Newline()
+        
+        self.rtc.WriteText('Start with plain text. ')
+        self.rtc.BeginBold()
+        self.rtc.WriteText('BeginBold() makes it bold. ')
+        self.rtc.BeginItalic()
+        self.rtc.WriteText('BeginItalic() makes it bold-italic. ')
+        self.rtc.EndBold()
+        self.rtc.WriteText('EndBold() should make it italic but instead makes it bold. ')
+        self.rtc.EndItalic()
+        self.rtc.WriteText('EndItalic() takes us back to plain text. ')
+        self.rtc.Newline()
+
+        self.rtc.WriteText('Start with plain text. ')
+        self.rtc.BeginBold()
+        self.rtc.WriteText('BeginBold() makes it bold. ')
+        self.rtc.BeginUnderline()
+        self.rtc.WriteText('BeginUnderline() makes it bold-underline. ')
+        self.rtc.EndBold()
+        self.rtc.WriteText('EndBold() should make it underline but instead makes it bold. ')
+        self.rtc.EndUnderline()
+        self.rtc.WriteText('EndUnderline() takes us back to plain text. ')
+        self.rtc.Newline()
+
+        self.rtc.WriteText('According to Julian, this functions "as expected" because of the way the RichTextCtrl is written.  I wrote the SetFontStyle() method here to demonstrate a way to work with overlapping styles that solves this problem.')
+        self.rtc.Newline()
+
+        # Create and initialize text attributes
+        self.textAttr = rt.RichTextAttr()
+        self.SetFontStyle(fontColor=wx.Colour(0, 0, 0), fontBgColor=wx.Colour(255, 255, 255), fontFace='Times New Roman', fontSize=10, fontBold=False, fontItalic=False, fontUnderline=False)
+        self.rtc.WriteText('Start with plain text. ')
+        self.SetFontStyle(fontBold=True)
+        self.rtc.WriteText('Bold. ')
+        self.SetFontStyle(fontItalic=True)
+        self.rtc.WriteText('Bold-italic. ')
+        self.SetFontStyle(fontBold=False)
+        self.rtc.WriteText('Italic. ')
+        self.SetFontStyle(fontItalic=False)
+        self.rtc.WriteText('Back to plain text. ')
+        self.rtc.Newline()
+
+        self.rtc.WriteText('Start with plain text. ')
+        self.SetFontStyle(fontBold=True)
+        self.rtc.WriteText('Bold. ')
+        self.SetFontStyle(fontUnderline=True)
+        self.rtc.WriteText('Bold-Underline. ')
+        self.SetFontStyle(fontBold=False)
+        self.rtc.WriteText('Underline. ')
+        self.SetFontStyle(fontUnderline=False)
+        self.rtc.WriteText('Back to plain text. ')
+        self.rtc.Newline()
         self.rtc.EndParagraphSpacing()
 
         self.rtc.EndSuppressUndo()
         self.rtc.Thaw()
         
 
+    def SetFontStyle(self, fontColor = None, fontBgColor = None, fontFace = None, fontSize = None,
+                     fontBold = None, fontItalic = None, fontUnderline = None):
+      if fontColor:
+         self.textAttr.SetTextColour(fontColor)
+      if fontBgColor:
+         self.textAttr.SetBackgroundColour(fontBgColor)
+      if fontFace:
+         self.textAttr.SetFontFaceName(fontFace)
+      if fontSize:
+         self.textAttr.SetFontSize(fontSize)
+      if fontBold != None:
+         if fontBold:
+            self.textAttr.SetFontWeight(wx.FONTWEIGHT_BOLD)
+         else:
+            self.textAttr.SetFontWeight(wx.FONTWEIGHT_NORMAL)
+      if fontItalic != None:
+         if fontItalic:
+            self.textAttr.SetFontStyle(wx.FONTSTYLE_ITALIC)
+         else:
+            self.textAttr.SetFontStyle(wx.FONTSTYLE_NORMAL)
+      if fontUnderline != None:
+         if fontUnderline:
+            self.textAttr.SetFontUnderlined(True)
+         else:
+            self.textAttr.SetFontUnderlined(False)
+      self.rtc.SetDefaultStyle(self.textAttr)
+
+    def OnURL(self, evt):
+        wx.MessageBox(evt.GetString(), "URL Clicked")
+        
+
     def OnFileOpen(self, evt):
         # This gives us a string suitable for the file dialog based on
         # the file handlers that are loaded
@@ -258,17 +349,17 @@ class RichTextFrame(wx.Frame):
         self.rtc.ApplyUnderlineToSelection()
         
     def OnAlignLeft(self, evt):
-        self.rtc.ApplyAlignmentToSelection(rt.TEXT_ALIGNMENT_LEFT)
+        self.rtc.ApplyAlignmentToSelection(wx.TEXT_ALIGNMENT_LEFT)
         
     def OnAlignRight(self, evt):
-        self.rtc.ApplyAlignmentToSelection(rt.TEXT_ALIGNMENT_RIGHT)
+        self.rtc.ApplyAlignmentToSelection(wx.TEXT_ALIGNMENT_RIGHT)
         
     def OnAlignCenter(self, evt):
-        self.rtc.ApplyAlignmentToSelection(rt.TEXT_ALIGNMENT_CENTRE)
+        self.rtc.ApplyAlignmentToSelection(wx.TEXT_ALIGNMENT_CENTRE)
         
     def OnIndentMore(self, evt):
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_LEFT_INDENT)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_LEFT_INDENT)
         ip = self.rtc.GetInsertionPoint()
         if self.rtc.GetStyle(ip, attr):
             r = rt.RichTextRange(ip, ip)
@@ -276,13 +367,13 @@ class RichTextFrame(wx.Frame):
                 r = self.rtc.GetSelectionRange()
 
             attr.SetLeftIndent(attr.GetLeftIndent() + 100)
-            attr.SetFlags(rt.TEXT_ATTR_LEFT_INDENT)
+            attr.SetFlags(wx.TEXT_ATTR_LEFT_INDENT)
             self.rtc.SetStyle(r, attr)
        
         
     def OnIndentLess(self, evt):
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_LEFT_INDENT)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_LEFT_INDENT)
         ip = self.rtc.GetInsertionPoint()
         if self.rtc.GetStyle(ip, attr):
             r = rt.RichTextRange(ip, ip)
@@ -291,13 +382,13 @@ class RichTextFrame(wx.Frame):
 
         if attr.GetLeftIndent() >= 100:
             attr.SetLeftIndent(attr.GetLeftIndent() - 100)
-            attr.SetFlags(rt.TEXT_ATTR_LEFT_INDENT)
+            attr.SetFlags(wx.TEXT_ATTR_LEFT_INDENT)
             self.rtc.SetStyle(r, attr)
 
         
     def OnParagraphSpacingMore(self, evt):
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_PARA_SPACING_AFTER)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_PARA_SPACING_AFTER)
         ip = self.rtc.GetInsertionPoint()
         if self.rtc.GetStyle(ip, attr):
             r = rt.RichTextRange(ip, ip)
@@ -305,13 +396,13 @@ class RichTextFrame(wx.Frame):
                 r = self.rtc.GetSelectionRange()
 
             attr.SetParagraphSpacingAfter(attr.GetParagraphSpacingAfter() + 20);
-            attr.SetFlags(rt.TEXT_ATTR_PARA_SPACING_AFTER)
+            attr.SetFlags(wx.TEXT_ATTR_PARA_SPACING_AFTER)
             self.rtc.SetStyle(r, attr)
 
         
     def OnParagraphSpacingLess(self, evt):
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_PARA_SPACING_AFTER)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_PARA_SPACING_AFTER)
         ip = self.rtc.GetInsertionPoint()
         if self.rtc.GetStyle(ip, attr):
             r = rt.RichTextRange(ip, ip)
@@ -320,48 +411,48 @@ class RichTextFrame(wx.Frame):
 
             if attr.GetParagraphSpacingAfter() >= 20:
                 attr.SetParagraphSpacingAfter(attr.GetParagraphSpacingAfter() - 20);
-                attr.SetFlags(rt.TEXT_ATTR_PARA_SPACING_AFTER)
+                attr.SetFlags(wx.TEXT_ATTR_PARA_SPACING_AFTER)
                 self.rtc.SetStyle(r, attr)
 
         
     def OnLineSpacingSingle(self, evt): 
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_LINE_SPACING)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_LINE_SPACING)
         ip = self.rtc.GetInsertionPoint()
         if self.rtc.GetStyle(ip, attr):
             r = rt.RichTextRange(ip, ip)
             if self.rtc.HasSelection():
                 r = self.rtc.GetSelectionRange()
 
-            attr.SetFlags(rt.TEXT_ATTR_LINE_SPACING)
+            attr.SetFlags(wx.TEXT_ATTR_LINE_SPACING)
             attr.SetLineSpacing(10)
             self.rtc.SetStyle(r, attr)
  
                 
     def OnLineSpacingHalf(self, evt):
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_LINE_SPACING)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_LINE_SPACING)
         ip = self.rtc.GetInsertionPoint()
         if self.rtc.GetStyle(ip, attr):
             r = rt.RichTextRange(ip, ip)
             if self.rtc.HasSelection():
                 r = self.rtc.GetSelectionRange()
 
-            attr.SetFlags(rt.TEXT_ATTR_LINE_SPACING)
+            attr.SetFlags(wx.TEXT_ATTR_LINE_SPACING)
             attr.SetLineSpacing(15)
             self.rtc.SetStyle(r, attr)
 
         
     def OnLineSpacingDouble(self, evt):
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_LINE_SPACING)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_LINE_SPACING)
         ip = self.rtc.GetInsertionPoint()
         if self.rtc.GetStyle(ip, attr):
             r = rt.RichTextRange(ip, ip)
             if self.rtc.HasSelection():
                 r = self.rtc.GetSelectionRange()
 
-            attr.SetFlags(rt.TEXT_ATTR_LINE_SPACING)
+            attr.SetFlags(wx.TEXT_ATTR_LINE_SPACING)
             attr.SetLineSpacing(20)
             self.rtc.SetStyle(r, attr)
 
@@ -373,17 +464,17 @@ class RichTextFrame(wx.Frame):
         r = self.rtc.GetSelectionRange()
         fontData = wx.FontData()
         fontData.EnableEffects(False)
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_FONT)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_FONT)
         if self.rtc.GetStyle(self.rtc.GetInsertionPoint(), attr):
-            fontData.SetInitialFont(attr.CreateFont())
+            fontData.SetInitialFont(attr.GetFont())
 
         dlg = wx.FontDialog(self, fontData)
         if dlg.ShowModal() == wx.ID_OK:
             fontData = dlg.GetFontData()
             font = fontData.GetChosenFont()
             if font:
-                attr.SetFlags(rt.TEXT_ATTR_FONT)
+                attr.SetFlags(wx.TEXT_ATTR_FONT)
                 attr.SetFont(font)
                 self.rtc.SetStyle(r, attr)
         dlg.Destroy()
@@ -391,8 +482,8 @@ class RichTextFrame(wx.Frame):
 
     def OnColour(self, evt):
         colourData = wx.ColourData()
-        attr = rt.TextAttrEx()
-        attr.SetFlags(rt.TEXT_ATTR_TEXT_COLOUR)
+        attr = wx.TextAttr()
+        attr.SetFlags(wx.TEXT_ATTR_TEXT_COLOUR)
         if self.rtc.GetStyle(self.rtc.GetInsertionPoint(), attr):
             colourData.SetColour(attr.GetTextColour())
 
@@ -405,7 +496,7 @@ class RichTextFrame(wx.Frame):
                     self.rtc.BeginTextColour(colour)
                 else:
                     r = self.rtc.GetSelectionRange()
-                    attr.SetFlags(rt.TEXT_ATTR_TEXT_COLOUR)
+                    attr.SetFlags(wx.TEXT_ATTR_TEXT_COLOUR)
                     attr.SetTextColour(colour)
                     self.rtc.SetStyle(r, attr)
         dlg.Destroy()
@@ -422,13 +513,13 @@ class RichTextFrame(wx.Frame):
         evt.Check(self.rtc.IsSelectionUnderlined())
     
     def OnUpdateAlignLeft(self, evt):
-        evt.Check(self.rtc.IsSelectionAligned(rt.TEXT_ALIGNMENT_LEFT))
+        evt.Check(self.rtc.IsSelectionAligned(wx.TEXT_ALIGNMENT_LEFT))
         
     def OnUpdateAlignCenter(self, evt):
-        evt.Check(self.rtc.IsSelectionAligned(rt.TEXT_ALIGNMENT_CENTRE))
+        evt.Check(self.rtc.IsSelectionAligned(wx.TEXT_ALIGNMENT_CENTRE))
         
     def OnUpdateAlignRight(self, evt):
-        evt.Check(self.rtc.IsSelectionAligned(rt.TEXT_ALIGNMENT_RIGHT))
+        evt.Check(self.rtc.IsSelectionAligned(wx.TEXT_ALIGNMENT_RIGHT))
 
     
     def ForwardEvent(self, evt):
@@ -521,45 +612,45 @@ class RichTextFrame(wx.Frame):
                 self.Bind(wx.EVT_UPDATE_UI, updateUI, item)
         
         tbar = self.CreateToolBar()
-        doBind( tbar.AddTool(-1, images.get_rt_openBitmap(),
+        doBind( tbar.AddTool(-1, images._rt_open.GetBitmap(),
                             shortHelpString="Open"), self.OnFileOpen)
-        doBind( tbar.AddTool(-1, images.get_rt_saveBitmap(),
+        doBind( tbar.AddTool(-1, images._rt_save.GetBitmap(),
                             shortHelpString="Save"), self.OnFileSave)
         tbar.AddSeparator()
-        doBind( tbar.AddTool(wx.ID_CUT, images.get_rt_cutBitmap(),
+        doBind( tbar.AddTool(wx.ID_CUT, images._rt_cut.GetBitmap(),
                             shortHelpString="Cut"), self.ForwardEvent, self.ForwardEvent)
-        doBind( tbar.AddTool(wx.ID_COPY, images.get_rt_copyBitmap(),
+        doBind( tbar.AddTool(wx.ID_COPY, images._rt_copy.GetBitmap(),
                             shortHelpString="Copy"), self.ForwardEvent, self.ForwardEvent)
-        doBind( tbar.AddTool(wx.ID_PASTE, images.get_rt_pasteBitmap(),
+        doBind( tbar.AddTool(wx.ID_PASTE, images._rt_paste.GetBitmap(),
                             shortHelpString="Paste"), self.ForwardEvent, self.ForwardEvent)
         tbar.AddSeparator()
-        doBind( tbar.AddTool(wx.ID_UNDO, images.get_rt_undoBitmap(),
+        doBind( tbar.AddTool(wx.ID_UNDO, images._rt_undo.GetBitmap(),
                             shortHelpString="Undo"), self.ForwardEvent, self.ForwardEvent)
-        doBind( tbar.AddTool(wx.ID_REDO, images.get_rt_redoBitmap(),
+        doBind( tbar.AddTool(wx.ID_REDO, images._rt_redo.GetBitmap(),
                             shortHelpString="Redo"), self.ForwardEvent, self.ForwardEvent)
         tbar.AddSeparator()
-        doBind( tbar.AddTool(-1, images.get_rt_boldBitmap(), isToggle=True,
+        doBind( tbar.AddTool(-1, images._rt_bold.GetBitmap(), isToggle=True,
                             shortHelpString="Bold"), self.OnBold, self.OnUpdateBold)
-        doBind( tbar.AddTool(-1, images.get_rt_italicBitmap(), isToggle=True,
+        doBind( tbar.AddTool(-1, images._rt_italic.GetBitmap(), isToggle=True,
                             shortHelpString="Italic"), self.OnItalic, self.OnUpdateItalic)
-        doBind( tbar.AddTool(-1, images.get_rt_underlineBitmap(), isToggle=True,
+        doBind( tbar.AddTool(-1, images._rt_underline.GetBitmap(), isToggle=True,
                             shortHelpString="Underline"), self.OnUnderline, self.OnUpdateUnderline)
         tbar.AddSeparator()
-        doBind( tbar.AddTool(-1, images.get_rt_alignleftBitmap(), isToggle=True,
+        doBind( tbar.AddTool(-1, images._rt_alignleft.GetBitmap(), isToggle=True,
                             shortHelpString="Align Left"), self.OnAlignLeft, self.OnUpdateAlignLeft)
-        doBind( tbar.AddTool(-1, images.get_rt_centreBitmap(), isToggle=True,
+        doBind( tbar.AddTool(-1, images._rt_centre.GetBitmap(), isToggle=True,
                             shortHelpString="Center"), self.OnAlignCenter, self.OnUpdateAlignCenter)
-        doBind( tbar.AddTool(-1, images.get_rt_alignrightBitmap(), isToggle=True,
+        doBind( tbar.AddTool(-1, images._rt_alignright.GetBitmap(), isToggle=True,
                             shortHelpString="Align Right"), self.OnAlignRight, self.OnUpdateAlignRight)
         tbar.AddSeparator()
-        doBind( tbar.AddTool(-1, images.get_rt_indentlessBitmap(),
+        doBind( tbar.AddTool(-1, images._rt_indentless.GetBitmap(),
                             shortHelpString="Indent Less"), self.OnIndentLess)
-        doBind( tbar.AddTool(-1, images.get_rt_indentmoreBitmap(),
+        doBind( tbar.AddTool(-1, images._rt_indentmore.GetBitmap(),
                             shortHelpString="Indent More"), self.OnIndentMore)
         tbar.AddSeparator()
-        doBind( tbar.AddTool(-1, images.get_rt_fontBitmap(),
+        doBind( tbar.AddTool(-1, images._rt_font.GetBitmap(),
                             shortHelpString="Font"), self.OnFont)
-        doBind( tbar.AddTool(-1, images.get_rt_colourBitmap(),
+        doBind( tbar.AddTool(-1, images._rt_colour.GetBitmap(),
                             shortHelpString="Font Colour"), self.OnColour)
 
         tbar.Realize()
