@@ -39,7 +39,7 @@ class MyFrame(wx.Frame):
         
 
 if __name__ == "__main__":
-    app = wx.PySimpleApp()
+    app = wx.App()
     frame = MyFrame()
     frame.Show()
     app.MainLoop()
