@@ -18,6 +18,6 @@ class TestFrame(wx.Frame):
         self.SetSizer(sizer)
         self.Fit()
 
-app = wx.PySimpleApp()
+app = wx.App()
 TestFrame().Show()
 app.MainLoop()
